@@ -1,10 +1,11 @@
 import pytest
-from qtpy import PYSIDE6, PYQT6
+
+from qtpy import PYQT6, PYSIDE6
 
 
 def test_qtsvg():
     """Test the qtpy.QtSvg namespace"""
-    from qtpy import QtSvg
+    QtSvg = pytest.importorskip("qtpy.QtSvg")
 
     if not (PYSIDE6 or PYQT6):
         assert QtSvg.QGraphicsSvgItem is not None
